import { type UseFetchOptions, useFetch } from '@vueuse/core';

export const useApi = () => {
  const apiHost: string =
    import.meta.env.VITE_API_HOST ?? 'http://localhost:5150/api/';

  const fullUrl = (path: string): string => {
    const apiHostEndsWithSlash = apiHost.endsWith('/');
    const pathStartsWithSlash = path.startsWith('/');
    if (apiHostEndsWithSlash && pathStartsWithSlash) {
      return apiHost + path.substring(1);
    }
    if (!apiHostEndsWithSlash && !pathStartsWithSlash) {
      return `${apiHost}/${path}`;
    }
    return apiHost + path;
  };

  const getApi = async <T>(path: string, options?: UseFetchOptions) =>
    useFetch<T>(fullUrl(path), {
      ...options,
    })
      .get()
      .json<T>();

  const postApi = <Payload, Data>(
    path: string,
    body: Payload,
    options?: UseFetchOptions,
  ) => useFetch<Data>(fullUrl(path), { ...options }).post(body);

  const putApi = <Payload, Data>(
    path: string,
    body: Payload,
    options?: UseFetchOptions,
  ) => useFetch<Data>(fullUrl(path), { ...options }).put(body);

  const patchApi = <Payload, Data>(
    path: string,
    body: Payload,
    options?: UseFetchOptions,
  ) => useFetch<Data>(fullUrl(path), { ...options }).patch(body);

  const deleteApi = <T>(path: string, options?: UseFetchOptions) =>
    useFetch<T>(fullUrl(path), { ...options })
      .delete()
      .json<T>();

  return { getApi, postApi, putApi, patchApi, deleteApi };
};
