import type {
  ResetPasswordRequest,
  VerifyAuth,
  ForgotPasswordRequest,
  LoginRequest,
  LoginResponse,
  RegisterRequest,
} from '@/models/auth';
import { useApi } from './api';
import { useAuthStore } from '@/stores/auth';

export const useAuth = () => {
  const api = useApi();
  const authStore = useAuthStore();

  const register = (name: string, password: string, email: string) =>
    api.postApi<RegisterRequest, null>('/auth/register', {
      name: name,
      password: password,
      email: email,
    });

  const verify = (token: string) =>
    api.postApi<VerifyAuth, null>('/auth/verify', { token: token });

  const login = (email: string, password: string) =>
    api.postApi<LoginRequest, LoginResponse>(
      '/auth/login',
      {
        email: email,
        password: password,
      },
      {
        afterFetch: (ctx) => {
          authStore.loginStatus = ctx.data;
          return ctx;
        },
      },
    );

  const forgot = (email: string) =>
    api.postApi<ForgotPasswordRequest, null>('/auth/forgot', { email: email });

  const reset = (token: string, password: string) =>
    api.postApi<ResetPasswordRequest, null>('/auth/reset', {
      token: token,
      password: password,
    });

  const logout = () => (authStore.loginStatus = null);

  return { register, verify, login, forgot, reset, logout };
};
